// packages/html-rewriter/src/plugin.ts
import { Plugin } from "@miniflare/shared";

// packages/html-rewriter/src/rewriter.ts
import { TransformStream } from "stream/web";
import { Response } from "@miniflare/core";
import { Response as BaseResponse } from "undici";
var HTMLRewriter = class {
  #elementHandlers = [];
  #documentHandlers = [];
  on(selector, handlers) {
    this.#elementHandlers.push([selector, handlers]);
    return this;
  }
  onDocument(handlers) {
    this.#documentHandlers.push(handlers);
    return this;
  }
  transform(response) {
    const body = response.body;
    if (body === null)
      return new Response(body, response);
    if (response instanceof BaseResponse) {
      response = new Response(response.body, response);
    }
    let rewriter;
    const transformStream = new TransformStream({
      start: async (controller) => {
        const { HTMLRewriter: BaseHTMLRewriter } = await import("html-rewriter-wasm");
        rewriter = new BaseHTMLRewriter((output) => {
          if (output.length !== 0)
            controller.enqueue(output);
        });
        for (const [selector, handlers] of this.#elementHandlers) {
          rewriter.on(selector, handlers);
        }
        for (const handlers of this.#documentHandlers) {
          rewriter.onDocument(handlers);
        }
      },
      transform: (chunk) => rewriter.write(chunk),
      flush: () => rewriter.end()
    });
    const promise = body.pipeTo(transformStream.writable);
    promise.catch(() => {
    }).finally(() => rewriter.free());
    const res = new Response(transformStream.readable, response);
    res.headers.delete("Content-Length");
    return res;
  }
};

// packages/html-rewriter/src/plugin.ts
var HTMLRewriterPlugin = class extends Plugin {
  constructor(ctx) {
    super(ctx);
  }
  setup() {
    return { globals: { HTMLRewriter } };
  }
};
export {
  HTMLRewriter,
  HTMLRewriterPlugin
};
//# sourceMappingURL=index.js.map
